# Release Notes
---

# 1.0.0 (2026-03-08)


### Bug Fixes

* Fix issues pointed by linter ([064cd65](https://github.com/arxlang/arxpm/commit/064cd6539e7baf1126ca24197d3c75c0bcee2105))
* Fix smoke tests ([06714de](https://github.com/arxlang/arxpm/commit/06714de295bd63e2b8de6b0a91b693ff24bd8ff6))

# Release Notes

---
